==> quote-observer-1.0.1.tgz: package/api/quote.js <==
/*
 * @Author: kael 
 * @Date: 2020-11-06 17:33:41 
 * @Last Modified by: kael
 * @Last Modified time: 2020-11-11 10:59:26
 */

// http://web.ifzq.gtimg.cn/appstock/app/usfqkline/get?_var=kline_dayqfq&param=usTSLA.OQ,day,,,10,qfq&r=0.2834233560574715
// http://web.ifzq.gtimg.cn/appstock/app/hkfqkline/get?_var=kline_dayqfq&param=hk00700,day,,,10,qfq&r=0.283423356057471500
// http://web.ifzq.gtimg.cn/appstock/app/fqkline/get?_var=kline_dayqfq&param=sz399006,day,,,10,qfq&r=0.4519900299757633000

const axios = require('axios');
const querystring = require('querystring');

const base_url = `http://web.ifzq.gtimg.cn/appstock/app`;
const path_mkt = {
  SH: `/fqkline/get`,
  SZ: `/fqkline/get`,
  HK: `/hkfqkline/get`,
  US: `/usfqkline/get`,
};

const fix_id = (id) => global.MARKET[id] || id;

function kline_dayqfq(id, days = 10) {
  let [mkt, code] = id.split('.');
  let _id = fix_id(`${mkt.toLowerCase()}${code}${'US' === mkt ? '.OQ' : ''}`);
  let _var = 'kline_dayqfq';
  let params = {
    _var,
    _r: Math.random(),
    param: `${_id},day,,,${days},qfq`,
  };
  return axios
    .get(`${base_url}${path_mkt[mkt]}?${querystring.stringify(params)}`)
    .then((raw = '') => {
      try {
        let resp = JSON.parse(raw.data.toString().replace(`${_var}=`, ''));
        let data = (resp || {}).data[_id] || [];
        let info = (data.qt || {})[_id] || [];
        return { id: _id, info, data: (data.day || data.qfqday).reverse() };
      } catch (error) {
        return {};
      }
    });
}

module.exports = {
  kline_dayqfq,
};

==> quote-observer-1.3.5.tgz: package/api/quote.js <==
/*
 * @Author: kael 
 * @Date: 2020-11-06 17:33:41 
 * @Last Modified by: kael
 * @Last Modified time: 2021-06-01 14:30:29
 */

// http://web.ifzq.gtimg.cn/appstock/app/usfqkline/get?_var=kline_dayqfq&param=usTSLA.OQ,day,,,10,qfq&r=0.2834233560574715
// http://web.ifzq.gtimg.cn/appstock/app/hkfqkline/get?_var=kline_dayqfq&param=hk00700,day,,,10,qfq&r=0.283423356057471500
// http://web.ifzq.gtimg.cn/appstock/app/fqkline/get?_var=kline_dayqfq&param=sz399006,day,,,10,qfq&r=0.4519900299757633000

const axios = require('axios');
const logger = require('../logger')();
const querystring = require('querystring');

const base_url = `http://web.ifzq.gtimg.cn/appstock/app`;
const path_mkt = {
  SH: `/fqkline/get`,
  SZ: `/fqkline/get`,
  HK: `/hkfqkline/get`,
  US: `/usfqkline/get`,
};

const fix_id = (id) => global.MARKET[id] || id;

function kline_dayqfq(id, days = 10) {
  let [mkt, code] = id.split('.');
  let _id = fix_id(`${mkt.toLowerCase()}${code}${'US' === mkt ? '.OQ' : ''}`);
  let _var = 'kline_dayqfq';
  let params = {
    _var,
    _r: Math.random(),
    param: `${_id},day,,,${days},qfq`,
  };
  let url = `${base_url}${path_mkt[mkt]}?${querystring.stringify(params)}`;
  logger.info(`Query ${id}: ${url}`);
  return axios
    .get(url)
    .then((raw = '') => {
      try {
        let resp = JSON.parse(raw.data.toString().replace(`${_var}=`, ''));
        let data = (resp || {}).data[_id] || [];
        let info = (data.qt || {})[_id] || [];
        return { fid: id, id: _id, info, data: (data.day || data.qfqday).reverse() };
      } catch (error) {
        logger.error(id, error);
        return {};
      }
    });
}

module.exports = {
  kline_dayqfq,
};
